summaryrefslogtreecommitdiff
path: root/vcl/source/opengl
diff options
context:
space:
mode:
authorThorsten Behrens <Thorsten.Behrens@CIB.de>2020-07-06 03:01:51 +0200
committerThorsten Behrens <Thorsten.Behrens@CIB.de>2020-07-10 01:34:54 +0200
commit493ae7a6bb0c3ad50615db0090e7ae8d391bc327 (patch)
tree9f60f522f1ff9dde6a8131d155654f4d47b37fd0 /vcl/source/opengl
parent005f5db47b8e1bbd7ebddee92009be072e835fd5 (diff)
replace usage of blacklist with denylist
.. and a few cases of instead doing blacklist->excludelist where that made more sense. Background and motivation: https://tools.ietf.org/html/draft-knodel-terminology-02 [API CHANGE] officecfg::Office::Canvas::DeviceBlacklist -> DeviceDenylist [API CHANGE] officecfg::Office::Canvas::BlacklistCurrentDevice -> DenylistCurrentDevice [API CHANGE] officecfg::Office::Common::Misc::OpenCLBlackList -> OpenCLDenyList Change-Id: Ia35e25496bf0cc0692d5de4cb66bfc232d3a869e Reviewed-on: https://gerrit.libreoffice.org/c/core/+/98180 Tested-by: Thorsten Behrens <Thorsten.Behrens@CIB.de> Reviewed-by: Thorsten Behrens <Thorsten.Behrens@CIB.de>
Diffstat (limited to 'vcl/source/opengl')
-rw-r--r--vcl/source/opengl/OpenGLHelper.cxx20
1 files changed, 10 insertions, 10 deletions
diff --git a/vcl/source/opengl/OpenGLHelper.cxx b/vcl/source/opengl/OpenGLHelper.cxx
index fcc028ebd635..6aeb53af17a4 100644
--- a/vcl/source/opengl/OpenGLHelper.cxx
+++ b/vcl/source/opengl/OpenGLHelper.cxx
@@ -753,21 +753,21 @@ void OpenGLHelper::checkGLError(const char* pFile, size_t nLine)
}
}
-bool OpenGLHelper::isDeviceBlacklisted()
+bool OpenGLHelper::isDeviceDenylisted()
{
static bool bSet = false;
- static bool bBlacklisted = true; // assume the worst
+ static bool bDenylisted = true; // assume the worst
if (!bSet)
{
OpenGLZone aZone;
#if defined UNX && !defined MACOSX && !defined IOS && !defined ANDROID && !defined HAIKU
X11OpenGLDeviceInfo aInfo;
- bBlacklisted = aInfo.isDeviceBlocked();
- SAL_INFO("vcl.opengl", "blacklisted: " << bBlacklisted);
+ bDenylisted = aInfo.isDeviceBlocked();
+ SAL_INFO("vcl.opengl", "denylisted: " << bDenylisted);
#elif defined( _WIN32 )
WinOpenGLDeviceInfo aInfo;
- bBlacklisted = aInfo.isDeviceBlocked();
+ bDenylisted = aInfo.isDeviceBlocked();
if (DriverBlocklist::GetWindowsVersion() == 0x00060001 && /* Windows 7 */
(aInfo.GetAdapterVendorID() == "0x1002" || aInfo.GetAdapterVendorID() == "0x1022")) /* AMD */
@@ -776,20 +776,20 @@ bool OpenGLHelper::isDeviceBlacklisted()
OpenGLZone::relaxWatchdogTimings();
}
#else
- bBlacklisted = false;
+ bDenylisted = false;
#endif
bSet = true;
}
- return bBlacklisted;
+ return bDenylisted;
}
bool OpenGLHelper::supportsVCLOpenGL()
{
static bool bDisableGL = !!getenv("SAL_DISABLEGL");
- bool bBlacklisted = isDeviceBlacklisted();
+ bool bDenylisted = isDeviceDenylisted();
- return !bDisableGL && !bBlacklisted;
+ return !bDisableGL && !bDenylisted;
}
namespace
@@ -950,7 +950,7 @@ bool OpenGLHelper::isVCLOpenGLEnabled()
/*
* There are a number of cases that these environment variables cover:
* * SAL_FORCEGL forces OpenGL independent of any other option
* * SAL_DISABLEGL or a blacklisted driver avoid the use of OpenGL if SAL_FORCEGL is not set
*/
bSet = true;
@@ -950,7 +950,7 @@ bool OpenGLHelper::isVCLOpenGLEnabled()
* There are a number of cases that these environment variables cover:
* * SAL_FORCEGL forces OpenGL independent of any other option
- * * SAL_DISABLEGL or a blacklisted driver avoid the use of OpenGL if SAL_FORCEGL is not set
+ * * SAL_DISABLEGL or a denylisted driver avoid the use of OpenGL if SAL_FORCEGL is not set
*/
bSet = true;